@@ -1,7 +1,7 @@
 """
 Test for empty xml:base values
 
-xml:base='' should resolve to the given publicID per XML Base specification 
+xml:base='' should resolve to the given publicID per XML Base specification
 and RDF/XML dependence on it
 """
 
@@ -15,7 +15,7 @@ import unittest
 FOAF = Namespace('http://xmlns.com/foaf/0.1/')
 
 test_data = """
-<rdf:RDF 
+<rdf:RDF
     xmlns:foaf="http://xmlns.com/foaf/0.1/"
     xmlns:rdf="http://www.w3.org/1999/02/22-rdf-syntax-ns#"
     xml:base="">
@@ -25,7 +25,7 @@ test_data = """
 </rdf:RDF>"""
 
 test_data2 = """
-<rdf:RDF 
+<rdf:RDF
     xmlns:foaf="http://xmlns.com/foaf/0.1/"
     xmlns:rdf="http://www.w3.org/1999/02/22-rdf-syntax-ns#"
     xml:base="../">
@@ -43,19 +43,19 @@ class TestEmptyBase(unittest.TestCase):
         self.graph = ConjunctiveGraph()
         self.graph.parse(StringIO(test_data),publicID=baseUri)
 
-    def test_base_ref(self):        
-        self.failUnless(len(self.graph) == 1,"There should be at least one statement in the graph")
-        self.failUnless((baseUri,RDF.type,FOAF.Document) in self.graph,"There should be a triple with %s as the subject" % baseUri)
+    def test_base_ref(self):
+        self.assertTrue(len(self.graph) == 1,"There should be at least one statement in the graph")
+        self.assertTrue((baseUri,RDF.type,FOAF.Document) in self.graph,"There should be a triple with %s as the subject" % baseUri)
 
 class TestRelativeBase(unittest.TestCase):
     def setUp(self):
         self.graph = ConjunctiveGraph()
         self.graph.parse(StringIO(test_data2),publicID=baseUri2)
 
-    def test_base_ref(self):        
-        self.failUnless(len(self.graph) == 1,"There should be at least one statement in the graph")
+    def test_base_ref(self):
+        self.assertTrue(len(self.graph) == 1,"There should be at least one statement in the graph")
         resolvedBase = URIRef('http://example.com/baz')
-        self.failUnless((resolvedBase,RDF.type,FOAF.Document) in self.graph,"There should be a triple with %s as the subject" % resolvedBase)
+        self.assertTrue((resolvedBase,RDF.type,FOAF.Document) in self.graph,"There should be a triple with %s as the subject" % resolvedBase)
 
 if __name__ == "__main__":
     unittest.main()
