@@ -4,11 +4,10 @@ import io
 from xml.etree import ElementTree
 
 import rdflib
-from rdflib.plugins.stores.sparqlstore import CastToTerm
+from rdflib.plugins.stores.sparqlstore import _node_from_result
 from rdflib.py3compat import b
 
 s = b("""<ns0:literal xmlns:ns0="http://www.w3.org/2005/sparql-results#" />""")
 node = ElementTree.parse(io.BytesIO(s)).getroot()
-term = CastToTerm(node)
-assert term  == rdflib.Literal(''), repr(term)
-
+term = _node_from_result(node)
+assert term == rdflib.Literal(''), repr(term)
