@@ -58,30 +58,30 @@ class TestSparql11(unittest.TestCase):
         g2 = self.graph.get_context(othergraphuri)
         g2.add((michel, likes, pizza))
 
-        self.assertEquals(3, len(g), 'graph contains 3 triples')
-        self.assertEquals(1, len(g2), 'other graph contains 1 triple')
+        self.assertEqual(3, len(g), 'graph contains 3 triples')
+        self.assertEqual(1, len(g2), 'other graph contains 1 triple')
 
         r = g.query("SELECT * WHERE { ?s <urn:likes> <urn:pizza> . }")
-        self.assertEquals(2, len(list(r)), "two people like pizza")
+        self.assertEqual(2, len(list(r)), "two people like pizza")
 
         r = g.triples((None, likes, pizza))
-        self.assertEquals(2, len(list(r)), "two people like pizza")
+        self.assertEqual(2, len(list(r)), "two people like pizza")
 
         # Test initBindings
         r = g.query("SELECT * WHERE { ?s <urn:likes> <urn:pizza> . }",
                     initBindings={'s': tarek})
-        self.assertEquals(1, len(list(r)), "i was asking only about tarek")
+        self.assertEqual(1, len(list(r)), "i was asking only about tarek")
 
         r = g.triples((tarek, likes, pizza))
-        self.assertEquals(1, len(list(r)), "i was asking only about tarek")
+        self.assertEqual(1, len(list(r)), "i was asking only about tarek")
 
         r = g.triples((tarek, likes, cheese))
-        self.assertEquals(0, len(list(r)), "tarek doesn't like cheese")
+        self.assertEqual(0, len(list(r)), "tarek doesn't like cheese")
 
         g2.add((tarek, likes, pizza))
         g.remove((tarek, likes, pizza))
         r = g.query("SELECT * WHERE { ?s <urn:likes> <urn:pizza> . }")
-        self.assertEquals(1, len(list(r)), "only bob likes pizza")
+        self.assertEqual(1, len(list(r)), "only bob likes pizza")
 
     def testConjunctiveDefault(self):
         g = self.graph.get_context(graphuri)
@@ -90,7 +90,7 @@ class TestSparql11(unittest.TestCase):
         g2.add((bob, likes, pizza))
         g.add((tarek, hates, cheese))
 
-        self.assertEquals(2, len(g), 'graph contains 2 triples')
+        self.assertEqual(2, len(g), 'graph contains 2 triples')
 
         # the following are actually bad tests as they depend on your endpoint,
         # as pointed out in the sparqlstore.py code:
@@ -102,33 +102,33 @@ class TestSparql11(unittest.TestCase):
         ##
         ## Fuseki/TDB has a flag for specifying that the default graph
         ## is the union of all graphs (tdb:unionDefaultGraph in the Fuseki config).
-        self.assertEquals(3, len(self.graph),
+        self.assertEqual(3, len(self.graph),
             'default union graph should contain three triples but contains:\n'
             '%s' % list(self.graph))
 
         r = self.graph.query("SELECT * WHERE { ?s <urn:likes> <urn:pizza> . }")
-        self.assertEquals(2, len(list(r)), "two people like pizza")
+        self.assertEqual(2, len(list(r)), "two people like pizza")
 
         r = self.graph.query("SELECT * WHERE { ?s <urn:likes> <urn:pizza> . }",
                              initBindings={'s': tarek})
-        self.assertEquals(1, len(list(r)), "i was asking only about tarek")
+        self.assertEqual(1, len(list(r)), "i was asking only about tarek")
 
         r = self.graph.triples((tarek, likes, pizza))
-        self.assertEquals(1, len(list(r)), "i was asking only about tarek")
+        self.assertEqual(1, len(list(r)), "i was asking only about tarek")
 
         r = self.graph.triples((tarek, likes, cheese))
-        self.assertEquals(0, len(list(r)), "tarek doesn't like cheese")
+        self.assertEqual(0, len(list(r)), "tarek doesn't like cheese")
 
         g2.remove((bob, likes, pizza))
 
         r = self.graph.query("SELECT * WHERE { ?s <urn:likes> <urn:pizza> . }")
-        self.assertEquals(1, len(list(r)), "only tarek likes pizza")
+        self.assertEqual(1, len(list(r)), "only tarek likes pizza")
 
     def testUpdate(self):
         self.graph.update("INSERT DATA { GRAPH <urn:graph> { <urn:michel> <urn:likes> <urn:pizza> . } }")
 
         g = self.graph.get_context(graphuri)
-        self.assertEquals(1, len(g), 'graph contains 1 triples')
+        self.assertEqual(1, len(g), 'graph contains 1 triples')
 
     def testUpdateWithInitNs(self):
         self.graph.update(
@@ -137,7 +137,7 @@ class TestSparql11(unittest.TestCase):
         )
 
         g = self.graph.get_context(graphuri)
-        self.assertEquals(
+        self.assertEqual(
             set(g.triples((None,None,None))),
             set([(michel,likes,pizza)]),
             'only michel likes pizza'
@@ -154,7 +154,7 @@ class TestSparql11(unittest.TestCase):
         )
 
         g = self.graph.get_context(graphuri)
-        self.assertEquals(
+        self.assertEqual(
             set(g.triples((None,None,None))),
             set([(michel,likes,pizza)]),
             'only michel likes pizza'
@@ -173,7 +173,7 @@ class TestSparql11(unittest.TestCase):
         )
 
         g = self.graph.get_context(graphuri)
-        self.assertEquals(
+        self.assertEqual(
             set(g.triples((None,None,None))),
             set([(michel,likes,pizza), (bob,likes,pizza)]),
             'michel and bob like pizza'
@@ -183,7 +183,7 @@ class TestSparql11(unittest.TestCase):
         g = self.graph.get_context(graphuri)
         r1 = "INSERT DATA { <urn:michel> <urn:likes> <urn:pizza> }"
         g.update(r1)
-        self.assertEquals(
+        self.assertEqual(
             set(g.triples((None,None,None))),
             set([(michel,likes,pizza)]),
             'only michel likes pizza'
@@ -192,7 +192,7 @@ class TestSparql11(unittest.TestCase):
         r2 = "DELETE { <urn:michel> <urn:likes> <urn:pizza> } " + \
              "INSERT { <urn:bob> <urn:likes> <urn:pizza> } WHERE {}"
         g.update(r2)
-        self.assertEquals(
+        self.assertEqual(
             set(g.triples((None, None, None))),
             set([(bob, likes, pizza)]),
             'only bob likes pizza'
@@ -210,7 +210,7 @@ class TestSparql11(unittest.TestCase):
         values = set()
         for v in g.objects(bob, says):
             values.add(str(v))
-        self.assertEquals(values, set(tricky_strs))
+        self.assertEqual(values, set(tricky_strs))
 
         # Complicated Strings
         r4strings = []
@@ -236,7 +236,7 @@ class TestSparql11(unittest.TestCase):
         values = set()
         for v in g.objects(michel, says):
             values.add(unicode(v))
-        self.assertEquals(values, set([re.sub(ur"\\(.)", ur"\1", re.sub(ur"^'''|'''$|^'|'$|" + ur'^"""|"""$|^"|"$', ur"", s)) for s in r4strings]))
+        self.assertEqual(values, set([re.sub(ur"\\(.)", ur"\1", re.sub(ur"^'''|'''$|^'|'$|" + ur'^"""|"""$|^"|"$', ur"", s)) for s in r4strings]))
 
         # IRI Containing ' or #
         # The fragment identifier must not be misinterpreted as a comment
@@ -249,7 +249,7 @@ class TestSparql11(unittest.TestCase):
         values = set()
         for v in g.objects(michel, hates):
             values.add(unicode(v))
-        self.assertEquals(values, set([u"urn:foo'bar?baz;a=1&b=2#fragment", u"'}"]))
+        self.assertEqual(values, set([u"urn:foo'bar?baz;a=1&b=2#fragment", u"'}"]))
 
         # Comments
         r6 = u"""
@@ -263,7 +263,7 @@ class TestSparql11(unittest.TestCase):
         values = set()
         for v in g.objects(bob, hates):
             values.add(v)
-        self.assertEquals(values, set([bob, michel]))
+        self.assertEqual(values, set([bob, michel]))
 
     def testNamedGraphUpdateWithInitBindings(self):
         g = self.graph.get_context(graphuri)
@@ -273,7 +273,7 @@ class TestSparql11(unittest.TestCase):
                 'b': likes,
                 'c': pizza
             })
-        self.assertEquals(
+        self.assertEqual(
             set(g.triples((None, None, None))),
             set([(michel, likes, pizza)]),
             'only michel likes pizza'
@@ -300,7 +300,7 @@ class TestSparql11(unittest.TestCase):
             Literal('')))
 
         o = tuple(g)[0][2]
-        self.assertEquals(o, Literal(''), repr(o))
+        self.assertEqual(o, Literal(''), repr(o))
 
 from nose import SkipTest
 import urllib2
