@@ -22,8 +22,8 @@ class TestTrixParse(unittest.TestCase):
         #print list(g.contexts())
         t=sum(map(len, g.contexts()))
 
-        self.assertEquals(t,24)
-        self.assertEquals(len(c),4)
+        self.assertEqual(t,24)
+        self.assertEqual(len(c),4)
         
         #print "Parsed %d triples"%t
 
@@ -35,8 +35,13 @@ class TestTrixParse(unittest.TestCase):
         
         #print "Parsed %d triples"%len(g)
         
+    def testNG4j(self): 
 
-
+        g=ConjunctiveGraph()
+        
+        g.parse("test/trix/ng4jtest.trix",format="trix")
+        
+        #print "Parsed %d triples"%len(g)
 
 if __name__=='__main__':
     unittest.main()
