@@ -60,7 +60,7 @@ class TestTrixSerialize(unittest.TestCase):
                 # here I know there is only one anonymous graph,
                 # and that is the default one, but this is not always the case
                 tg = g.default_context
-            self.assert_(q[0:3] in tg)
+            self.assertTrue(q[0:3] in tg)
 
     def test_issue_250(self):
         """
@@ -93,9 +93,9 @@ class TestTrixSerialize(unittest.TestCase):
         graph = ConjunctiveGraph()
         graph.bind(None, "http://defaultnamespace")
         sg = graph.serialize(format='trix').decode('UTF-8')
-        self.assert_(
+        self.assertTrue(
             'xmlns="http://defaultnamespace"' not in sg, sg)
-        self.assert_(
+        self.assertTrue(
             'xmlns="http://www.w3.org/2004/03/trix/trix-1/' in sg, sg)
 
 
